//
// "This sample program is provided AS IS and may be used, executed, copied and modified without royalty payment by customer (a) for its own 
// instruction and study, (b) in order to develop applications designed to run with an IBM WebSphere product, either for customer's own internal use 
// or for redistribution by customer, as part of such an application, in customer's own products. "
//
// Product 5630-A36,  (C) COPYRIGHT International Business Machines Corp., 2001, 2002
// All Rights Reserved * Licensed Materials - Property of IBM
//
package com.ibm.websphere.samples.j2eeappclients.classloader;

public class ClassLoaderClientMain
{
	public static void main(String[] args) 
	{
		System.out.println("Beginning Test");

        // The class-loader heirarchy is as follows:
        //  Runtime Classpath Patches
        //    <WAS_HOME>\classes
        //  Runtime Classpath
        //    <WAS_HOME>\lib
        //  Runtime Extensions
        //    <WAS_HOME>\lib\ext
        //  Application Extensions
        //    <WAS_HOME>\lib\app
        //  Application Classloaders
        //    WAR/JAR files in EAR set by MANIFEST.MF

        // Use the Class Loader for our thread.
        // The System class loader and the one used to load this class
        // should be the same.  Using Class.forName() or New should work the same
        ClassLoader cl = Thread.currentThread().getContextClassLoader();

        // Try Loading a class from our Client Jar
        // - These classes are automatically available through the Application Classloader
        Class clsAppClientJar = null;
        try {
            System.out.println("Attempting to load ClassLoaderClientJarTest");
            clsAppClientJar = cl.loadClass("com.ibm.websphere.samples.j2eeappclients.classloader.ClassLoaderClientJarTest");

            // Print out the class name
            System.out.println("  Loaded: " + clsAppClientJar.toString());
        }
        catch (java.lang.ClassNotFoundException ex) {
            System.out.println("  Unable to load class");
        }

        // Try Loading a class from a different jar within the EAR
        // - This is defined in the MANIFEST.MF file in the Client jar and is available through
        //   the Application Classloader
        Class clsClientCommonJar = null;
        try {
            System.out.println("Attempting to load ClassLoaderClientCommonJarTest");
            clsClientCommonJar = cl.loadClass("com.ibm.websphere.samples.j2eeappclients.classloader.ClassLoaderClientCommonJarTest");

            // Print out the class name
            System.out.println("  Loaded: " + clsClientCommonJar.toString());
        }
        catch (java.lang.ClassNotFoundException ex) {
            System.out.println("  Unable to load class");
        }

        // Try Loading a class from the EAR itself
        // - This is defined in the MANIFEST.MF file in the Client jar and is available through
        //   the Application Classloader
        Class clsEAR = null;
        try {
            System.out.println("Attempting to load ClassLoaderClientEARTest");
            clsEAR = cl.loadClass("com.ibm.websphere.samples.j2eeappclients.classloader.ClassLoaderClientEARTest");

            // Print out the class name
            System.out.println("  Loaded: " + clsEAR.toString());
        }
        catch (java.lang.ClassNotFoundException ex) {
            System.out.println("  Unable to load class");
        }

        // Try loading a class from the classpath 
        // This will never work.  The WebSphere class loaders require that classes
        // be loaded from within the EAR or from pre-determined WebSphere directories.
        Class clsLocal = null;
        try {
            System.out.println("Attempting to load ClassLoaderLocalTest");
            clsLocal = cl.loadClass("com.ibm.websphere.samples.j2eeappclients.classloader.ClassLoaderLocalTest");

            // Print out the class name
            System.out.println("  Loaded: " + clsLocal.toString());
        }
        catch (java.lang.ClassNotFoundException ex) {
            System.out.println("  Unable to load class");
        }
        
		System.exit(0);
	}
}
