//
// "This sample program is provided AS IS and may be used, executed, copied and modified without royalty payment by customer (a) for its own 
// instruction and study, (b) in order to develop applications designed to run with an IBM WebSphere product, either for customer's own internal use 
// or for redistribution by customer, as part of such an application, in customer's own products. "
//
// Product 5630-A36,  (C) COPYRIGHT International Business Machines Corp., 2001, 2002
// All Rights Reserved * Licensed Materials - Property of IBM
//
package com.ibm.websphere.samples.j2eeappclients.launchapi;

import java.lang.*;
import java.io.FileInputStream;
import java.util.Properties;
import java.lang.reflect.Method;

/**
 * Standalone Java class with main() that will create the
 * J2EE Application Client Container environment using the
 * launch() api and execute the application inside the
 * EAR file that is passed in.
 */
public class LaunchAPIMain 
{
    /**
     * Execute the application.
     * @param String[] args: EAR filename, property filename and optional application arguments
     */
	public static void main(String[] args) 
	{
        // Retrieve our input parameters:
        //  Ear File Name
        //  Properties file
        //  Arguments (optional)

        if (args.length < 2) {
            System.out.println("Incorrect syntax.");
            System.out.println("  Correct syntax:  java LaunchAPIMain <ear file> <property file> [optional arguments]");
            return;
        }

        String earFileName = args[0];
        String propFileName = args[1];
        Properties p = null;
        try {
            FileInputStream propFIS = new FileInputStream(propFileName); 
            p = new Properties(); 
            p.load(propFIS);
        }
        catch (Throwable ex) {
            ex.printStackTrace();
            return;
        }
        
        String[] appArgs = null;
        if (args.length > 2) {
            appArgs = new String[args.length-2];
            for(int i=2;i<args.length;i++) {
                appArgs[i-2] = args[i];
            }
        }
        
        // New-up the launchClient class
        Class clslc = null;
        Object lc = null;
        try {
            clslc = Class.forName("com.ibm.websphere.client.applicationclient.launchClient");
            lc = clslc.newInstance();
        }
        catch (Throwable ex) {
            System.out.println("Unable to initialize launchClient.  See stack trace for details:");
            ex.printStackTrace();
            return;
        }


        try {
            // Get the launch method from the launchClient class using reflection
            Class[] launchParamTypes = {String.class, Properties.class, String[].class};
            Method launch = clslc.getMethod("launch", launchParamTypes);

            // Launch the J2EE application
            Object[] launchArgs = {earFileName, p, appArgs};
            launch.invoke(lc, launchArgs);
        }
        catch (Throwable ex) {
            System.out.println("launch() failed.  See stack trace for details:");
            ex.printStackTrace();
            return;
        }
    }
}
